searchData={"items":[{"type":"module","title":"OpenApiSpex.Schemax","doc":"Similar to `Ecto.Schema`, define Schema of Open Api Spec as DSL syntax.\n\n## `schema` macro\n\nTo define schema, use `schema/2` macro. It must be used once in a module.\n\n`schema/2` macro define a function named `schema/0`, which return a `%OpenApiSpex.Schema{}` struct.\nThe first argument of `schema/2` macro is required and it become `:title` field of the struct.\n\n#","ref":"OpenApiSpex.Schemax.html"},{"type":"module","title":"Example - OpenApiSpex.Schemax","doc":"defmodule SimpleUser do\n      use OpenApiSpex.Schemax\n\n      @required [:id, :name]\n      schema \"SimpleUser\" do\n        property :id, :integer\n        property :name, :string\n        property :is_verified, :boolean\n      end\n    end\n\nwhen you call the created function `schema/0`, it will show:\n\n    iex> SimpleUser.schema()\n    %OpenApiSpex.Schema{\n      title: \"SimpleUser\",\n      type: :object,\n      properties: %{id: %OpenApiSpex.Schema{type: :integer},\n      name: %OpenApiSpex.Schema{type: :string},\n      is_verified: %OpenApiSpex.Schema{type: :boolean}},\n      required: [:id, :name]\n    }\n\n\n## `embedded_schema/2` macro\n\nUnlike `schema/2`, `embedded_schema/2` macro can be defined multiple time in a module.\nSometimes when you have deep nested schema, it is bothering that turn every schema into modules.\nIn that case, you might want to temporary schemas in a module, which you can do through this macro.\nWhen you define this macro, unlike `schema` macro, put function name into\nfirst argument of macro instead of title.\nAfter that, when you want to use that embedded schema, call that function name.\n\ndefine both of `:schema_type` and `:required` fields are also included in do block,\nunlike `schema` macro which defines them as module attributes.\n\n#","ref":"OpenApiSpex.Schemax.html#module-example"},{"type":"module","title":"Example - OpenApiSpex.Schemax","doc":"defmodule ListResponse do\n      use OpenApiSpex.Schemax\n\n      schema \"ListResponse\" do\n        property :list, list()\n      end\n\n      embedded_schema :list do\n        property :id, :integer\n        property :name, :string\n        required [:id, :name]\n      end\n    end","ref":"OpenApiSpex.Schemax.html#module-example"},{"type":"macro","title":"OpenApiSpex.Schemax.embedded_schema/2","doc":"","ref":"OpenApiSpex.Schemax.html#embedded_schema/2"},{"type":"function","title":"OpenApiSpex.Schemax.maybe_properties_map/1","doc":"","ref":"OpenApiSpex.Schemax.html#maybe_properties_map/1"},{"type":"macro","title":"OpenApiSpex.Schemax.schema/2","doc":"","ref":"OpenApiSpex.Schemax.html#schema/2"},{"type":"function","title":"OpenApiSpex.Schemax.wrapper/2","doc":"Wrapper function for convenient.\nFor example, if there is a User schema, it can make a response like `%{\"user\" => %User{...}}`.\n\nNOTE: This is not recommended. please use `embedded_schema/2` instead.","ref":"OpenApiSpex.Schemax.html#wrapper/2"},{"type":"module","title":"OpenApiSpex.Schemax.Parser","doc":"This module is Parser for `OpenApiSpex.Schemax.schema/2` macro.\n\nIn case of `:property`, this module converts camelCase fields\nof `OpenApiSpex.Schema` struct to snake_case fields.\n\nWe will change this module to support more advanced parsing.","ref":"OpenApiSpex.Schemax.Parser.html"},{"type":"function","title":"OpenApiSpex.Schemax.Parser.parse_body/1","doc":"","ref":"OpenApiSpex.Schemax.Parser.html#parse_body/1"},{"type":"function","title":"OpenApiSpex.Schemax.Parser.parse_lines/1","doc":"","ref":"OpenApiSpex.Schemax.Parser.html#parse_lines/1"}],"content_type":"text/markdown"}